diff --git a/web/pgadmin/browser/__init__.py b/web/pgadmin/browser/__init__.py
index 9ee756374..84dda935f 100644
--- a/web/pgadmin/browser/__init__.py
+++ b/web/pgadmin/browser/__init__.py
@@ -542,6 +542,78 @@ def _get_logout_url():
         url_for('security.logout'), url_for(BROWSER_INDEX))
 
 
+def _get_browser_supported():
+    browser = request.user_agent.browser
+    version = request.user_agent.version and int(
+        request.user_agent.version.split('.')[0])
+
+    browser_name = None
+    browser_known = True
+    if browser == 'chrome' and version < 72:
+        browser_name = 'Chrome'
+    elif browser == 'firefox' and version < 65:
+        browser_name = 'Firefox'
+    # comparing EdgeHTML engine version
+    elif browser == 'edge' and version < 18:
+        browser_name = 'Edge'
+        # browser version returned by edge browser is actual EdgeHTML
+        # engine version. Below code gets actual browser version using
+        # EdgeHTML version
+        engine_to_actual_browser_version = {
+            16: 41,
+            17: 42,
+            18: 44
+        }
+        version = engine_to_actual_browser_version.get(version, '< 44')
+    elif browser == 'safari' and version < 12:
+        browser_name = 'Safari'
+    elif browser == 'msie':
+        browser_name = 'Internet Explorer'
+    elif browser != 'chrome' and browser != 'firefox' and \
+            browser != 'edge' and browser != 'safari':
+        browser_name = browser
+        browser_known = False
+
+    return browser_name, browser_known, version
+
+
+def check_browser_upgrade():
+    data = None
+    url = '%s?version=%s' % (config.UPGRADE_CHECK_URL, config.APP_VERSION)
+    current_app.logger.debug('Checking version data at: %s' % url)
+
+    try:
+        # Do not wait for more than 5 seconds.
+        # It stuck on rendering the browser.html, while working in the
+        # broken network.
+        if os.path.exists(config.CA_FILE):
+            response = urlopen(url, data, 5, cafile=config.CA_FILE)
+        else:
+            response = urlopen(url, data, 5)
+        current_app.logger.debug(
+            'Version check HTTP response code: %d' % response.getcode()
+        )
+
+        if response.getcode() == 200:
+            data = json.loads(response.read().decode('utf-8'))
+            current_app.logger.debug('Response data: %s' % data)
+    except Exception:
+        current_app.logger.exception('Exception when checking for update')
+
+    if data is not None and \
+        data[config.UPGRADE_CHECK_KEY]['version_int'] > \
+            config.APP_VERSION_INT:
+        msg = render_template(
+            MODULE_NAME + "/upgrade.html",
+            current_version=config.APP_VERSION,
+            upgrade_version=data[config.UPGRADE_CHECK_KEY]['version'],
+            product_name=config.APP_NAME,
+            download_url=data[config.UPGRADE_CHECK_KEY]['download_url']
+        )
+
+        flash(msg, 'warning')
+
+
 @blueprint.route("/")
 @pgCSRFProtect.exempt
 @login_required
@@ -563,36 +635,7 @@ def index():
     # NOTE: If the checks here are updated, make sure the supported versions
     # at https://www.pgadmin.org/faq/#11 are updated to match!
     if config.CHECK_SUPPORTED_BROWSER:
-        browser = request.user_agent.browser
-        version = request.user_agent.version and int(
-            request.user_agent.version.split('.')[0])
-
-        browser_name = None
-        browser_known = True
-        if browser == 'chrome' and version < 72:
-            browser_name = 'Chrome'
-        elif browser == 'firefox' and version < 65:
-            browser_name = 'Firefox'
-        # comparing EdgeHTML engine version
-        elif browser == 'edge' and version < 18:
-            browser_name = 'Edge'
-            # browser version returned by edge browser is actual EdgeHTML
-            # engine version. Below code gets actual browser version using
-            # EdgeHTML version
-            engine_to_actual_browser_version = {
-                16: 41,
-                17: 42,
-                18: 44
-            }
-            version = engine_to_actual_browser_version.get(version, '< 44')
-        elif browser == 'safari' and version < 12:
-            browser_name = 'Safari'
-        elif browser == 'msie':
-            browser_name = 'Internet Explorer'
-        elif browser != 'chrome' and browser != 'firefox' and \
-                browser != 'edge' and browser != 'safari':
-            browser_name = browser
-            browser_known = False
+        browser_name, browser_known, version = _get_browser_supported()
 
         if browser_name is not None:
             msg = render_template(
@@ -607,40 +650,7 @@ def index():
     # Get the current version info from the website, and flash a message if
     # the user is out of date, and the check is enabled.
     if config.UPGRADE_CHECK_ENABLED:
-        data = None
-        url = '%s?version=%s' % (config.UPGRADE_CHECK_URL, config.APP_VERSION)
-        current_app.logger.debug('Checking version data at: %s' % url)
-
-        try:
-            # Do not wait for more than 5 seconds.
-            # It stuck on rendering the browser.html, while working in the
-            # broken network.
-            if os.path.exists(config.CA_FILE):
-                response = urlopen(url, data, 5, cafile=config.CA_FILE)
-            else:
-                response = urlopen(url, data, 5)
-            current_app.logger.debug(
-                'Version check HTTP response code: %d' % response.getcode()
-            )
-
-            if response.getcode() == 200:
-                data = json.loads(response.read().decode('utf-8'))
-                current_app.logger.debug('Response data: %s' % data)
-        except Exception:
-            current_app.logger.exception('Exception when checking for update')
-
-        if data is not None and \
-            data[config.UPGRADE_CHECK_KEY]['version_int'] > \
-                config.APP_VERSION_INT:
-            msg = render_template(
-                MODULE_NAME + "/upgrade.html",
-                current_version=config.APP_VERSION,
-                upgrade_version=data[config.UPGRADE_CHECK_KEY]['version'],
-                product_name=config.APP_NAME,
-                download_url=data[config.UPGRADE_CHECK_KEY]['download_url']
-            )
-
-            flash(msg, 'warning')
+        check_browser_upgrade()
 
     auth_only_internal = False
     auth_source = []
diff --git a/web/pgadmin/browser/server_groups/servers/databases/foreign_data_wrappers/foreign_servers/user_mappings/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/foreign_data_wrappers/foreign_servers/user_mappings/__init__.py
index a22387dbb..10d80ad04 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/foreign_data_wrappers/foreign_servers/user_mappings/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/foreign_data_wrappers/foreign_servers/user_mappings/__init__.py
@@ -530,6 +530,27 @@ class UserMappingView(PGChildNodeView, SchemaDiffObjectCompare):
 
         return cascade, data
 
+    def _fetch_specified_user_mapping_properties(self, umid):
+        try:
+            sql = render_template("/".join([self.template_path,
+                                            'properties.sql']),
+                                  umid=umid, conn=self.conn)
+            status, res = self.conn.execute_dict(sql)
+            if not status:
+                return internal_server_error(errormsg=res)
+
+            if not res['rows']:
+                return make_json_response(
+                    status=410,
+                    success=0,
+                    errormsg=gettext(
+                        'The specified user mapping could not be found.\n'
+                    )
+                )
+            return res
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
     @check_precondition
     def delete(self, gid, sid, did, fid, fsid, **kwargs):
         """
@@ -573,22 +594,7 @@ class UserMappingView(PGChildNodeView, SchemaDiffObjectCompare):
                             'could not be found.\n'
                         )
                     )
-
-                sql = render_template("/".join([self.template_path,
-                                                self._PROPERTIES_SQL]),
-                                      umid=umid, conn=self.conn)
-                status, res = self.conn.execute_dict(sql)
-                if not status:
-                    return internal_server_error(errormsg=res)
-
-                if not res['rows']:
-                    return make_json_response(
-                        status=410,
-                        success=0,
-                        errormsg=gettext(
-                            'The specified user mapping could not be found.\n'
-                        )
-                    )
+                res = self._fetch_specified_user_mapping_properties(umid)
 
                 data = res['rows'][0]
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/domains/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/domains/__init__.py
index bc62024a7..4a4c9b43d 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/domains/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/domains/__init__.py
@@ -606,6 +606,19 @@ AND relkind != 'c'))"""
             )
         )
 
+    def _check_cascade_operation(self, only_sql):
+        """
+        Check cascade operation.
+        :param only_sql:
+        :return:
+        """
+        if self.cmd == 'delete' or only_sql:
+            # This is a cascade operation
+            cascade = True
+        else:
+            cascade = False
+        return cascade
+
     @check_precondition
     def delete(self, gid, sid, did, scid, doid=None, only_sql=False):
         """
@@ -626,11 +639,7 @@ AND relkind != 'c'))"""
         else:
             data = {'ids': [doid]}
 
-        if self.cmd == 'delete' or only_sql:
-            # This is a cascade operation
-            cascade = True
-        else:
-            cascade = False
+        cascade = self._check_cascade_operation(only_sql)
 
         for doid in data['ids']:
             SQL = render_template("/".join([self.template_path,
@@ -810,6 +819,26 @@ AND relkind != 'c'))"""
         except Exception as e:
             return internal_server_error(errormsg=str(e))
 
+    def check_domain_type(self, data, old_data, is_schema_diff):
+        """
+        Check domain type
+        :return:
+        """
+        # If fulltype or basetype or collname is changed while comparing
+        # two schemas then we need to drop domain and recreate it
+        if 'fulltype' in data or 'basetype' in data or 'collname' in data:
+            SQL = render_template(
+                "/".join([self.template_path, 'domain_schema_diff.sql']),
+                data=data, o_data=old_data)
+        else:
+            if is_schema_diff:
+                data['is_schema_diff'] = True
+
+            SQL = render_template(
+                "/".join([self.template_path, 'update.sql']),
+                data=data, o_data=old_data)
+        return SQL, data
+
     def get_sql(self, gid, sid, data, scid, doid=None, is_schema_diff=False):
         """
         Generates the SQL statements to create/update the Domain.
@@ -852,19 +881,7 @@ AND relkind != 'c'))"""
 
             old_data['constraints'] = con_data
 
-            # If fulltype or basetype or collname is changed while comparing
-            # two schemas then we need to drop domain and recreate it
-            if 'fulltype' in data or 'basetype' in data or 'collname' in data:
-                SQL = render_template(
-                    "/".join([self.template_path, 'domain_schema_diff.sql']),
-                    data=data, o_data=old_data)
-            else:
-                if is_schema_diff:
-                    data['is_schema_diff'] = True
-
-                SQL = render_template(
-                    "/".join([self.template_path, self._UPDATE_SQL]),
-                    data=data, o_data=old_data)
+            SQL, data = self.check_domain_type(data, old_data, is_schema_diff)
             return SQL.strip('\n'), data['name'] if 'name' in data else \
                 old_data['name']
         else:
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/row_security_policies/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/row_security_policies/__init__.py
index 8402aecd1..03e17a4f1 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/row_security_policies/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/row_security_policies/__init__.py
@@ -436,6 +436,23 @@ class RowSecurityView(PGChildNodeView):
         except Exception as e:
             return internal_server_error(errormsg=str(e))
 
+    @staticmethod
+    def get_policy_data(plid):
+        """
+        return policy data
+        :param plid:
+        :return: policy id
+        """
+        if plid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [plid]}
+
+        return data
+
+
     @check_precondition
     def delete(self, gid, sid, did, scid, tid, **kwargs):
         """
@@ -459,12 +476,7 @@ class RowSecurityView(PGChildNodeView):
         else:
             cascade = False
 
-        if plid is None:
-            data = request.form if request.form else json.loads(
-                request.data, encoding='utf-8'
-            )
-        else:
-            data = {'ids': [plid]}
+        data = self.get_policy_data(plid)
 
         for plid in data['ids']:
             try:
diff --git a/web/pgadmin/tools/debugger/__init__.py b/web/pgadmin/tools/debugger/__init__.py
index 42097e36e..5543698da 100644
--- a/web/pgadmin/tools/debugger/__init__.py
+++ b/web/pgadmin/tools/debugger/__init__.py
@@ -2130,10 +2130,31 @@ def poll_result(trans_id):
     )
 
 
+def release_connection(manager, dbg_obj):
+    """This function is used to release connection."""
+    conn = manager.connection(
+        did=dbg_obj['database_id'],
+        conn_id=dbg_obj['conn_id'])
+    if conn.connected():
+        conn.cancel_transaction(
+            dbg_obj['conn_id'],
+            dbg_obj['database_id'])
+    manager.release(conn_id=dbg_obj['conn_id'])
+
+    if 'exe_conn_id' in dbg_obj:
+        conn = manager.connection(
+            did=dbg_obj['database_id'],
+            conn_id=dbg_obj['exe_conn_id'])
+        if conn.connected():
+            conn.cancel_transaction(
+                dbg_obj['exe_conn_id'],
+                dbg_obj['database_id'])
+        manager.release(conn_id=dbg_obj['exe_conn_id'])
+
+
 def close_debugger_session(_trans_id, close_all=False):
     """
-    This function is used to cancel the debugger transaction and
-    release the connection.
+    This function is used to cancel the debugger transaction.
 
     :param trans_id: Transaction id
     :return:
@@ -2154,24 +2175,7 @@ def close_debugger_session(_trans_id, close_all=False):
                     connection_manager(dbg_obj['server_id'])
 
                 if manager is not None:
-                    conn = manager.connection(
-                        did=dbg_obj['database_id'],
-                        conn_id=dbg_obj['conn_id'])
-                    if conn.connected():
-                        conn.cancel_transaction(
-                            dbg_obj['conn_id'],
-                            dbg_obj['database_id'])
-                    manager.release(conn_id=dbg_obj['conn_id'])
-
-                    if 'exe_conn_id' in dbg_obj:
-                        conn = manager.connection(
-                            did=dbg_obj['database_id'],
-                            conn_id=dbg_obj['exe_conn_id'])
-                        if conn.connected():
-                            conn.cancel_transaction(
-                                dbg_obj['exe_conn_id'],
-                                dbg_obj['database_id'])
-                        manager.release(conn_id=dbg_obj['exe_conn_id'])
+                    release_connection(manager, dbg_obj)
 
             de_inst.clear()
         except Exception:
